=======
Credits
=======

Development Lead
----------------

* Jan C. Rivenaes <jriv@equinor.com>

Contributors (code or valuable suggestions)
-------------------------------------------

(forgive if someone is forgotten)

* Trine Alsos (tral@equinor.com)
* Håvard Berland (havb@equinor.com)
* Per Olav Eide Svendsen (peesv@equinor.com)
